'filesysobjects.FileSysObjects' - Module
****************************************

.. automodule:: filesysobjects.FileSysObjects

Functions
---------

setUpperTreeSearchPath
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: setUpperTreeSearchPath

findRelPathInUpperTree
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: findRelPathInUpperTree

